@@ -25,9 +25,9 @@ import (
 
 	"github.com/urfave/cli"
 
+	"github.com/opencontainers/umoci/internal/funchelpers"
 	"github.com/opencontainers/umoci/oci/cas/dir"
 	"github.com/opencontainers/umoci/oci/casext"
-	"github.com/opencontainers/umoci/pkg/funchelpers"
 )
 
 var gcCommand = cli.Command{
