@@ -25,6 +25,7 @@ import (
 
 	"github.com/urfave/cli"
 
+	"github.com/opencontainers/umoci/internal/assert"
 	"github.com/opencontainers/umoci/oci/casext"
 	"github.com/opencontainers/umoci/oci/casext/blobcompress"
 )
@@ -252,6 +253,16 @@ func uxLayout(cmd cli.Command) cli.Command {
 	return cmd
 }
 
+func uxRootless(cmd cli.Command) cli.Command {
+	cmd.Flags = append(cmd.Flags, []cli.Flag{
+		cli.BoolFlag{
+			Name:  "rootless",
+			Usage: "enable rootless command support",
+		},
+	}...)
+	return cmd
+}
+
 func uxRemap(cmd cli.Command) cli.Command {
 	cmd.Flags = append(cmd.Flags, []cli.Flag{
 		cli.StringSliceFlag{
@@ -262,13 +273,8 @@ func uxRemap(cmd cli.Command) cli.Command {
 			Name:  "gid-map",
 			Usage: "specifies a gid mapping to use (container:host:size)",
 		},
-		cli.BoolFlag{
-			Name:  "rootless",
-			Usage: "enable rootless command support",
-		},
 	}...)
-
-	return cmd
+	return uxRootless(cmd)
 }
 
 // fetchMeta returns the requested metadata from the current [cli.Context] as
@@ -280,10 +286,9 @@ func fetchMeta[T any](ctx *cli.Context, metaName string) (T, bool) {
 		return *new(T), false
 	}
 	realVal, ok := val.(T)
-	if !ok {
-		// this is a programmer error
-		panic(fmt.Sprintf("umoci cli internal error: fetching cli metadata %s with wrong type %T", metaName, *new(T)))
-	}
+	assert.Assertf(ok,
+		"umoci cli internal error: fetching cli metadata %s with wrong type %T",
+		metaName, *new(T)) // programmer error
 	return realVal, true
 }
 
@@ -291,8 +296,7 @@ func fetchMeta[T any](ctx *cli.Context, metaName string) (T, bool) {
 // metadata is not present in the current [cli.Context].
 func mustFetchMeta[T any](ctx *cli.Context, metaName string) T {
 	val, ok := fetchMeta[T](ctx, metaName)
-	if !ok {
-		panic("umoci cli internal error: required cli metadata " + metaName + " missing")
-	}
+	assert.Assertf(ok,
+		"umoci cli internal error: required cli metadata %s missing", metaName) // programmer error
 	return val
 }
