@@ -1,6 +1,7 @@
+// SPDX-License-Identifier: Apache-2.0
 /*
  * umoci: Umoci Modifies Open Containers' Images
- * Copyright (C) 2016-2020 SUSE LLC
+ * Copyright (C) 2016-2025 SUSE LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -19,14 +20,14 @@ package casext
 
 import (
 	"context"
+	"fmt"
 
 	"github.com/apex/log"
 	"github.com/opencontainers/go-digest"
 	ispec "github.com/opencontainers/image-spec/specs-go/v1"
-	"github.com/pkg/errors"
 )
 
-// GCPolicy is a policy function that returns 'true' if a blob can be GC'ed
+// GCPolicy is a policy function that returns 'true' if a blob can be GC'ed.
 type GCPolicy func(ctx context.Context, digest digest.Digest) (bool, error)
 
 // GC will perform a mark-and-sweep garbage collection of the OCI image
@@ -45,30 +46,30 @@ type GCPolicy func(ctx context.Context, digest digest.Digest) (bool, error)
 // blob is skipped for garbage collection if a policy returns false.
 func (e Engine) GC(ctx context.Context, policies ...GCPolicy) error {
 	// Generate the root set of descriptors.
-	var root []ispec.Descriptor
 
 	index, err := e.GetIndex(ctx)
 	if err != nil {
-		return errors.Wrap(err, "get top-level index")
+		return fmt.Errorf("get top-level index: %w", err)
 	}
 
+	roots := make([]ispec.Descriptor, 0, len(index.Manifests))
 	for _, descriptor := range index.Manifests {
 		log.WithFields(log.Fields{
 			"digest": descriptor.Digest,
 		}).Debugf("GC: got reference")
-		root = append(root, descriptor)
+		roots = append(roots, descriptor)
 	}
 
 	// Mark from the root sets.
 	black := map[digest.Digest]struct{}{}
-	for idx, descriptor := range root {
+	for idx, descriptor := range roots {
 		log.WithFields(log.Fields{
 			"digest": descriptor.Digest,
 		}).Debugf("GC: marking from root")
 
 		reachables, err := e.reachable(ctx, descriptor)
 		if err != nil {
-			return errors.Wrapf(err, "getting reachables from root %d", idx)
+			return fmt.Errorf("getting reachables from root %d: %w", idx, err)
 		}
 		for _, reachable := range reachables {
 			black[reachable] = struct{}{}
@@ -78,7 +79,7 @@ func (e Engine) GC(ctx context.Context, policies ...GCPolicy) error {
 	// Sweep all blobs in the white set.
 	blobs, err := e.ListBlobs(ctx)
 	if err != nil {
-		return errors.Wrap(err, "get blob list")
+		return fmt.Errorf("get blob list: %w", err)
 	}
 
 	n := 0
@@ -92,7 +93,7 @@ sweep:
 		for i, policy := range policies {
 			ok, err := policy(ctx, digest)
 			if err != nil {
-				return errors.Wrapf(err, "invoking policy %d failed", i)
+				return fmt.Errorf("invoking policy %d failed: %w", i, err)
 			}
 
 			if !ok {
@@ -104,14 +105,14 @@ sweep:
 		log.Debugf("garbage collecting blob: %s", digest)
 
 		if err := e.DeleteBlob(ctx, digest); err != nil {
-			return errors.Wrapf(err, "remove unmarked blob %s", digest)
+			return fmt.Errorf("remove unmarked blob %s: %w", digest, err)
 		}
 		n++
 	}
 
 	// Finally, tell CAS to GC it.
 	if err := e.Clean(ctx); err != nil {
-		return errors.Wrapf(err, "clean engine")
+		return fmt.Errorf("clean engine: %w", err)
 	}
 
 	log.Debugf("garbage collected %d blobs", n)
