@@ -1,5 +1,4 @@
 //go:build linux
-// +build linux
 
 // SPDX-License-Identifier: Apache-2.0
 /*
@@ -34,8 +33,8 @@ import (
 	"github.com/stretchr/testify/require"
 	"golang.org/x/sys/unix"
 
+	"github.com/opencontainers/umoci/internal/system"
 	"github.com/opencontainers/umoci/pkg/fseval"
-	"github.com/opencontainers/umoci/pkg/system"
 )
 
 func testNeedsMknod(t *testing.T) {
@@ -87,7 +86,6 @@ func TestUnpackEntry_OverlayfsRootfs_Whiteout(t *testing.T) {
 	testNeedsMknod(t)
 
 	for _, userxattr := range []bool{true, false} {
-		userxattr := userxattr // copy iterator
 		t.Run(fmt.Sprintf("UserXattr=%v", userxattr), func(t *testing.T) {
 			dir := t.TempDir()
 
@@ -123,7 +121,6 @@ func TestUnpackEntry_OverlayfsRootfs_OpaqueWhiteout(t *testing.T) {
 	testNeedsMknod(t)
 
 	for _, userxattr := range []bool{true, false} {
-		userxattr := userxattr // copy iterator
 		t.Run(fmt.Sprintf("UserXattr=%v", userxattr), func(t *testing.T) {
 			dir := t.TempDir()
 
@@ -164,7 +161,6 @@ func TestUnpackEntry_OverlayfsRootfs_Whiteout_MissingDirs(t *testing.T) {
 	testNeedsMknod(t)
 
 	for _, userxattr := range []bool{true, false} {
-		userxattr := userxattr // copy iterator
 		t.Run(fmt.Sprintf("UserXattr=%v", userxattr), func(t *testing.T) {
 			dir := t.TempDir()
 
@@ -214,7 +210,6 @@ func TestUnpackEntry_OverlayfsRootfs_Whiteout_Nested(t *testing.T) {
 	testNeedsMknod(t)
 
 	for _, userxattr := range []bool{true, false} {
-		userxattr := userxattr // copy iterator
 		t.Run(fmt.Sprintf("UserXattr=%v", userxattr), func(t *testing.T) {
 			dir := t.TempDir()
 
@@ -271,7 +266,6 @@ func TestUnpackEntry_OverlayfsRootfs_OpaqueWhiteoutConvert(t *testing.T) {
 	testNeedsMknod(t)
 
 	for _, userxattr := range []bool{true, false} {
-		userxattr := userxattr // copy iterator
 		t.Run(fmt.Sprintf("UserXattr=%v", userxattr), func(t *testing.T) {
 			dir := t.TempDir()
 
