@@ -38,15 +38,15 @@ import (
 	rspec "github.com/opencontainers/runtime-spec/specs-go"
 
 	"github.com/opencontainers/umoci/internal"
+	"github.com/opencontainers/umoci/internal/funchelpers"
+	"github.com/opencontainers/umoci/internal/idtools"
+	"github.com/opencontainers/umoci/internal/system"
 	"github.com/opencontainers/umoci/oci/cas"
 	"github.com/opencontainers/umoci/oci/casext"
 	"github.com/opencontainers/umoci/oci/casext/blobcompress"
 	"github.com/opencontainers/umoci/oci/casext/mediatype"
 	iconv "github.com/opencontainers/umoci/oci/config/convert"
 	"github.com/opencontainers/umoci/pkg/fseval"
-	"github.com/opencontainers/umoci/pkg/funchelpers"
-	"github.com/opencontainers/umoci/pkg/idtools"
-	"github.com/opencontainers/umoci/pkg/system"
 )
 
 // AfterLayerUnpackCallback is called after each layer is unpacked.
@@ -83,7 +83,7 @@ const RootfsName = "rootfs"
 func isLayerType(mediaType string) bool {
 	layerMediaType, _ := mediatype.SplitMediaTypeSuffix(mediaType)
 	switch layerMediaType {
-	case ispec.MediaTypeImageLayerNonDistributable:
+	case ispec.MediaTypeImageLayerNonDistributable: //nolint:staticcheck // we need to support this deprecated media-type
 		log.Infof("image contains layers using the deprecated 'non-distributable' media type %q", layerMediaType)
 		fallthrough
 	case ispec.MediaTypeImageLayer:
