@@ -1,6 +1,7 @@
+// SPDX-License-Identifier: Apache-2.0
 /*
  * umoci: Umoci Modifies Open Containers' Images
- * Copyright (C) 2016-2020 SUSE LLC
+ * Copyright (C) 2016-2025 SUSE LLC
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -23,9 +24,10 @@ import (
 	"path/filepath"
 	"time"
 
-	"github.com/opencontainers/umoci/pkg/unpriv"
 	"github.com/vbatts/go-mtree"
 	"golang.org/x/sys/unix"
+
+	"github.com/opencontainers/umoci/pkg/unpriv"
 )
 
 // Rootless is an FsEval implementation that uses "umoci/pkg/unpriv".*
@@ -102,29 +104,29 @@ func (fs unprivFsEval) MkdirAll(path string, perm os.FileMode) error {
 	return unpriv.MkdirAll(path, perm)
 }
 
-// Llistxattr is equivalent to unpriv.Llistxattr
+// Llistxattr is equivalent to unpriv.Llistxattr.
 func (fs unprivFsEval) Llistxattr(path string) ([]string, error) {
 	return unpriv.Llistxattr(path)
 }
 
-// Lremovexattr is equivalent to unpriv.Lremovexattr
+// Lremovexattr is equivalent to unpriv.Lremovexattr.
 func (fs unprivFsEval) Lremovexattr(path, name string) error {
 	return unpriv.Lremovexattr(path, name)
 }
 
-// Lsetxattr is equivalent to unpriv.Lsetxattr
+// Lsetxattr is equivalent to unpriv.Lsetxattr.
 func (fs unprivFsEval) Lsetxattr(path, name string, value []byte, flags int) error {
 	return unpriv.Lsetxattr(path, name, value, flags)
 }
 
-// Lgetxattr is equivalent to unpriv.Lgetxattr
+// Lgetxattr is equivalent to unpriv.Lgetxattr.
 func (fs unprivFsEval) Lgetxattr(path string, name string) ([]byte, error) {
 	return unpriv.Lgetxattr(path, name)
 }
 
-// Lclearxattrs is equivalent to unpriv.Lclearxattrs
-func (fs unprivFsEval) Lclearxattrs(path string, except map[string]struct{}) error {
-	return unpriv.Lclearxattrs(path, except)
+// Lclearxattrs is equivalent to unpriv.Lclearxattrs.
+func (fs unprivFsEval) Lclearxattrs(path string, skipFn func(xattrName string) bool) error {
+	return unpriv.Lclearxattrs(path, skipFn)
 }
 
 // KeywordFunc returns a wrapper around the given mtree.KeywordFunc.
